==> 0.0.8%2B4.tar.gz: lib/table/config_table.dart <==
import 'package:eyflutter_core/dio/beans/retrofit.dart';
import 'package:eyflutter_core/dio/dio_manager.dart';
import 'package:eyflutter_core/dio/enums/method.dart';
import 'package:eyflutter_core/ey_flutter.dart';
import 'package:eyflutter_core/kit/timer/system.dart';
import 'package:eyflutter_core/kit/utils/dynamic_utils.dart';
import 'package:eyflutter_core/kit/utils/json_utils.dart';
import 'package:eyflutter_core/kit/utils/map/map_extension.dart';
import 'package:eyflutter_core/kit/utils/string/json_extension.dart';
import 'package:eyflutter_core/kit/utils/string/string_extension.dart';
import 'package:eyflutter_core/kit/utils/string/url_extension.dart';
import 'package:eyflutter_core/storage/memory_utils.dart';

class ConfigTable {
  factory ConfigTable() => _getInstance();

  static ConfigTable get instance => _getInstance();
  static ConfigTable? _instance;

  static ConfigTable _getInstance() {
    return _instance ??= new ConfigTable._internal();
  }

  ConfigTable._internal();

  Map<String, String> _tempMap = {};
  String _configCacheKey = "d954677b2383f5f9";
  String _prevSyncTimeKey = "26e4574ac4fa303a";
  String _appKey = "";
  String? _configData;
  int? _prevSyncTime;

  String _getAppKey() {
    if (_appKey.isEmptyString) {
      _appKey = EyFlutter.instance.appConfig?.appKey ?? "";
    }
    return _appKey;
  }

  /// 获取配置值
  /// [configKey] 配置表健
  Future<String> getValue({required String configKey}) {
    if (_tempMap.containsKey(configKey)) {
      var value = _tempMap.getValue<String>(configKey);
      return Future.value(value);
    }
    return _fromCacheTake(configKey);
  }

  /// 获取配置值
  /// [configKey] 配置表健
  Future<int> getDigitValue({required String configKey}) async {
    var value = await this.getValue(configKey: configKey);
    return Future.value(value.toInt);
  }

  /// 获取配置值
  /// [configKey] 配置表健
  Future<bool> getStateValue({required String configKey}) async {
    var value = await this.getValue(configKey: configKey);
    return Future.value(value.isTrue);
  }

  Future<String> _match(String configKey, String configData, bool isFromCache) {
    String matchValue = "";
    Map<String, dynamic> map = JsonUtils.fromJson(configData);
    map.forEach((key, value) {
      if (value is String) {
        if (configKey.isNotEmptyString && (key == configKey)) {
          matchValue = value.trim();
        }
        _tempMap[key] = value;
      }
    });
    if (isFromCache && matchValue.isEmptyString) {
      return _fromNetTake(configKey);
    } else {
      return Future.value(matchValue);
    }
  }

  Future<String> _fromCacheTake(String configKey) async {
    if (_configData.isNotEmptyString) {
      return _match(configKey, _configData!, false);
    }
    _configData = MemoryUtils.instance.getString("${_getAppKey()}_${configKey}");
    if (_configData.isEmptyJson) {
      return _fromNetTake(configKey);
    }
    return _match(configKey, _configData!, true);
  }

  Future<String> _fromNetTake(String configKey) async {
    var config = EyFlutter.instance.appConfig;
    var url = config?.configUrl() ?? "";
    if (!url.isUrl) {
      return Future.value("");
    }
    Retrofit retrofit = Retrofit(api: url, method: Method.GET);
    var response = await DioManager.instance.asyncRequestString(retrofit: retrofit);
    if (response.isEmptyString) {
      return Future.value("");
    }
    _configData = response;
    MemoryUtils.instance.set("${_getAppKey()}_${_configCacheKey}", response);
    _prevSyncTime = System.currentTimeMillis;
    MemoryUtils.instance.set("${_getAppKey()}_${_prevSyncTimeKey}", _prevSyncTime!);
    return _match(configKey, response, false);
  }

  void _accessibilityNetTake(Function() complete) {
    _fromNetTake("").then((netTake) {
      if (_configData.isEmptyString) {
        _accessibilityNetTake(complete);
      } else {
        complete();
      }
    });
  }

  /// 同步配置表(在应用启动时调用)
  /// [complete] 同步完成
  void syncConfigTable({required Function() complete}) {
    var timeDiff = System.currentTimeMillis - (_prevSyncTime ?? 0);
    if (_configData.isEmptyString || timeDiff >= 3600000) {
      var configCache = MemoryUtils.instance.getString("${_getAppKey()}_${_configCacheKey}");
      if (configCache.isEmptyString || EyFlutter.instance.isDebug()) {
        _accessibilityNetTake(complete);
      } else {
        var time = MemoryUtils.instance.getInt("${_getAppKey()}_${_prevSyncTimeKey}");
        var currentTime = System.currentTimeMillis;
        var diff = currentTime - time;
        if (diff >= 3600000) {
          _accessibilityNetTake(complete);
        } else {
          complete();
        }
      }
    } else {
      complete();
    }
  }
}

==> 0.0.9%2B4.tar.gz: lib/table/config_table.dart <==
import 'package:eyflutter_core/dio/beans/retrofit.dart';
import 'package:eyflutter_core/dio/dio_manager.dart';
import 'package:eyflutter_core/dio/enums/method.dart';
import 'package:eyflutter_core/ey_flutter.dart';
import 'package:eyflutter_core/kit/timer/system.dart';
import 'package:eyflutter_core/kit/utils/dynamic_utils.dart';
import 'package:eyflutter_core/kit/utils/json_utils.dart';
import 'package:eyflutter_core/kit/utils/map/map_extension.dart';
import 'package:eyflutter_core/kit/utils/string/json_extension.dart';
import 'package:eyflutter_core/kit/utils/string/string_extension.dart';
import 'package:eyflutter_core/kit/utils/string/url_extension.dart';
import 'package:eyflutter_core/storage/mmkv_utils.dart';

class ConfigTable {
  factory ConfigTable() => _getInstance();

  static ConfigTable get instance => _getInstance();
  static ConfigTable? _instance;

  static ConfigTable _getInstance() {
    return _instance ??= new ConfigTable._internal();
  }

  ConfigTable._internal();

  Map<String, String> _tempMap = {};
  String _configCacheKey = "d954677b2383f5f9";
  String _prevSyncTimeKey = "26e4574ac4fa303a";
  String _appKey = "";
  String? _configData;
  int _prevSyncTime = 0;

  String _getAppKey() {
    if (_appKey.isEmptyString) {
      _appKey = EyFlutter.instance.appConfig?.appKey ?? "";
    }
    return _appKey;
  }

  /// 获取配置值
  /// [configKey] 配置表健
  Future<String> getValue({required String configKey}) {
    if (_tempMap.containsKey(configKey)) {
      var value = _tempMap.getValue<String>(configKey);
      return Future.value(value);
    }
    return _fromCacheTake(configKey);
  }

  /// 获取配置值
  /// [configKey] 配置表健
  Future<int> getDigitValue({required String configKey}) async {
    var value = await this.getValue(configKey: configKey);
    return Future.value(value.toInt);
  }

  /// 获取配置值
  /// [configKey] 配置表健
  Future<bool> getStateValue({required String configKey}) async {
    var value = await this.getValue(configKey: configKey);
    return Future.value(value.isTrue);
  }

  Future<String> _match(String configKey, String configData, bool isFromCache) {
    String matchValue = "";
    Map<String, dynamic> map = JsonUtils.fromJson(configData);
    map.forEach((key, value) {
      if (value is String) {
        if (configKey.isNotEmptyString && (key == configKey)) {
          matchValue = value.trim();
        }
        _tempMap[key] = value;
      }
    });
    if (isFromCache && matchValue.isEmptyString) {
      return _fromNetTake(configKey);
    } else {
      return Future.value(matchValue);
    }
  }

  Future<String> _fromCacheTake(String configKey) async {
    if (_configData.isNotEmptyString) {
      return _match(configKey, _configData!, false);
    }
    _configData = await _getCacheConfig();
    if (_configData.isEmptyJson) {
      return _fromNetTake(configKey);
    }
    return _match(configKey, _configData!, true);
  }

  Future<String> _fromNetTake(String configKey) async {
    var config = EyFlutter.instance.appConfig;
    var url = config?.configUrl() ?? "";
    if (!url.isUrl) {
      return Future.value("");
    }
    Retrofit retrofit = Retrofit(api: url, method: Method.GET, cacheKey: "f5e445f9a5096c2c", cacheTime: 180000);
    var response = await DioManager.instance.asyncRequestString(retrofit: retrofit);
    if (response.isEmptyString) {
      return Future.value("");
    }
    _configData = response;
    MmkvUtils.instance.putString("${_getAppKey()}_${_configCacheKey}", value: response, part: MMkvPart.normal);
    _prevSyncTime = System.currentTimeMillis;
    MmkvUtils.instance.putInt("${_getAppKey()}_${_prevSyncTimeKey}", value: _prevSyncTime, part: MMkvPart.state);
    return _match(configKey, response, false);
  }

  void _accessibilityNetTake(Function() complete) {
    _fromNetTake("").then((netTake) {
      if (_configData.isEmptyString) {
        _accessibilityNetTake(complete);
      } else {
        complete();
      }
    });
  }

  //获取上一次时间
  Future<int> _getPrevTime() async {
    if (_prevSyncTime <= 0) {
      var time = await MmkvUtils.instance.getInt("${_getAppKey()}_${_prevSyncTimeKey}", part: MMkvPart.state);
      _prevSyncTime = time ?? 0;
    }
    return Future.value(_prevSyncTime);
  }

  Future<String?> _getCacheConfig() {
    if (_configData.isNotEmptyString) {
      return Future.value(_configData);
    }
    return MmkvUtils.instance.getString("${_getAppKey()}_${_configCacheKey}", part: MMkvPart.normal);
  }

  /// 同步配置表(在应用启动时调用)
  /// [complete] 同步完成
  void syncConfigTable({required Function() complete}) {
    if (EyFlutter.instance.isDebug()) {
      _accessibilityNetTake(complete);
    } else {
      _getCacheConfig().then((configCache) {
        if (configCache.isEmptyString) {
          _accessibilityNetTake(complete);
        } else {
          _getPrevTime().then((prevTime) {
            var timeDiff = System.currentTimeMillis - prevTime;
            if (timeDiff >= 3600000) {
              _accessibilityNetTake(complete);
            } else {
              complete();
            }
          });
        }
      });
    }
  }
}
